@@ -61,12 +61,8 @@ typedef struct st_mroonga_share
   int                 token_filters_length;
   plugin_ref          plugin;
   handlerton          *hton;
-  char                **index_table;
-  char                **key_tokenizer;
   char                **col_flags;
   char                **col_type;
-  uint                *index_table_length;
-  uint                *key_tokenizer_length;
   uint                *col_flags_length;
   uint                *col_type_length;
   uint                *wrap_key_nr;
@@ -98,7 +94,7 @@ struct st_mrn_slot_data
 };
 
 #define MRN_SET_WRAP_ALTER_KEY(file, ha_alter_info) \
-  Alter_inplace_info::HA_ALTER_FLAGS base_handler_flags = ha_alter_info->handler_flags; \
+  mrn_alter_flags base_handler_flags = ha_alter_info->handler_flags; \
   KEY  *base_key_info_buffer = ha_alter_info->key_info_buffer; \
   uint base_key_count = ha_alter_info->key_count; \
   uint base_index_drop_count = ha_alter_info->index_drop_count; \
@@ -151,8 +147,6 @@ void mrn_get_partition_info(const char *table_name, uint table_name_length,
 #endif
 int mrn_parse_table_param(MRN_SHARE *share, TABLE *table);
 bool mrn_is_geo_key(const KEY *key_info);
-int mrn_add_index_param(MRN_SHARE *share, KEY *key_info, int i);
-int mrn_parse_index_param(MRN_SHARE *share, TABLE *table);
 int mrn_add_column_param(MRN_SHARE *share, Field *field, int i);
 int mrn_parse_column_param(MRN_SHARE *share, TABLE *table);
 MRN_SHARE *mrn_get_share(const char *table_name, TABLE *table, int *error);
@@ -163,7 +157,11 @@ MRN_LONG_TERM_SHARE *mrn_get_long_term_share(const char *table_name,
                                              int *error);
 void mrn_free_long_term_share(MRN_LONG_TERM_SHARE *long_term_share);
 TABLE_SHARE *mrn_get_table_share(TABLE_LIST *table_list, int *error);
-TABLE_SHARE *mrn_create_tmp_table_share(TABLE_LIST *table_list, const char *path,
+TABLE_SHARE *mrn_create_tmp_table_share(TABLE_LIST *table_list,
+                                        const char *path,
+#ifdef MRN_OPEN_TABLE_DEF_USE_TABLE_DEFINITION
+                                        const dd::Table *table_def,
+#endif
                                         int *error);
 void mrn_free_tmp_table_share(TABLE_SHARE *table_share);
 KEY *mrn_create_key_info_for_table(MRN_SHARE *share, TABLE *table, int *error);
